==> climetlab_wekeo_datasets-0.1.1.tar.gz: climetlab_wekeo_datasets-0.1.1/climetlab_wekeo_datasets/ecmwf/satellite_upper_troposphere_humidity.py <==
#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.ecmwf.main import Main


class satellite_upper_troposphere_humidity(Main):
    name = "EO:ECMWF:DAT:SATELLITE_UPPER_TROPOSPHERE_HUMIDITY"
    dataset = "EO:ECMWF:DAT:SATELLITE_UPPER_TROPOSPHERE_HUMIDITY"

    choices = [
        "sensor_on_satellite",
        "variable",
        "format_",
    ]

    string_selects = [
        "day",
        "month",
        "year",
    ]

    @normalize(
        "day",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
            "16",
            "17",
            "18",
            "19",
            "20",
            "21",
            "22",
            "23",
            "24",
            "25",
            "26",
            "27",
            "28",
            "29",
            "30",
            "31",
        ],
        multiple=True,
    )
    @normalize(
        "month",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
        ],
        multiple=True,
    )
    @normalize(
        "year",
        [
            "1999",
            "2000",
            "2001",
            "2002",
            "2003",
            "2004",
            "2005",
            "2006",
            "2007",
            "2008",
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
            "2021",
        ],
        multiple=True,
    )
    @normalize("area", "bounding-box(list)")
    @normalize(
        "sensor_on_satellite",
        [
            "amsu_b_on_noaa_15",
            "amsu_b_on_noaa_16",
            "amsu_b_on_noaa_17",
            "mhs_on_metop_a",
            "mhs_on_metop_b",
            "mhs_on_metop_c",
            "mhs_on_noaa_18",
            "mhs_on_noaa_19",
        ],
    )
    @normalize(
        "format_",
        [
            "tgz",
            "zip",
        ],
    )
    @normalize(
        "variable",
        [
            "all",
        ],
    )
    def __init__(
        self,
        day,
        month,
        year,
        area=None,
        sensor_on_satellite=None,
        format_=None,
        variable="all",
    ):
        super().__init__(
            day=day,
            month=month,
            year=year,
            area=area,
            sensor_on_satellite=sensor_on_satellite,
            format_=format_,
            variable=variable,
        )

==> climetlab_wekeo_datasets-0.3.0.tar.gz: climetlab_wekeo_datasets-0.3.0/climetlab_wekeo_datasets/ecmwf/satellite_upper_troposphere_humidity.py <==
#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_datasets.ecmwf.main import Main


class satellite_upper_troposphere_humidity(Main):
    name = "EO:ECMWF:DAT:SATELLITE_UPPER_TROPOSPHERE_HUMIDITY"
    dataset = "EO:ECMWF:DAT:SATELLITE_UPPER_TROPOSPHERE_HUMIDITY"

    @normalize(
        "day",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
            "16",
            "17",
            "18",
            "19",
            "20",
            "21",
            "22",
            "23",
            "24",
            "25",
            "26",
            "27",
            "28",
            "29",
            "30",
            "31",
        ],
        multiple=True,
    )
    @normalize(
        "month",
        [
            "01",
            "02",
            "03",
            "04",
            "05",
            "06",
            "07",
            "08",
            "09",
            "10",
            "11",
            "12",
        ],
        multiple=True,
    )
    @normalize(
        "sensor_on_satellite",
        [
            "amsu_b_on_noaa_15",
            "amsu_b_on_noaa_16",
            "amsu_b_on_noaa_17",
            "mhs_on_metop_a",
            "mhs_on_metop_b",
            "mhs_on_metop_c",
            "mhs_on_noaa_18",
            "mhs_on_noaa_19",
        ],
    )
    @normalize(
        "year",
        [
            "1999",
            "2000",
            "2001",
            "2002",
            "2003",
            "2004",
            "2005",
            "2006",
            "2007",
            "2008",
            "2009",
            "2010",
            "2011",
            "2012",
            "2013",
            "2014",
            "2015",
            "2016",
            "2017",
            "2018",
            "2019",
            "2020",
            "2021",
        ],
        multiple=True,
    )
    @normalize(
        "variable",
        [
            "all",
        ],
    )
    @normalize("bbox", "bounding-box(list)")
    @normalize(
        "format_",
        [
            "tgz",
            "zip",
        ],
    )
    def __init__(
        self,
        day,
        month,
        sensor_on_satellite,
        year,
        variable="all",
        bbox=None,
        format_=None,
        limit=None,
    ):
        super().__init__(
            day=day,
            month=month,
            sensor_on_satellite=sensor_on_satellite,
            year=year,
            variable=variable,
            bbox=bbox,
            format_=format_,
            limit=limit,
        )
